@@ -28,7 +28,7 @@ class BaiduTest(seldom.TestCase):
         page.open("https://www.baidu.com")
         page.input.send_keys("seldom")
         page.button.click()
-        self.assertTitle("seldom_百度搜索")
+        self.assertElement(page.asser_ele)
 
 
 if __name__ == '__main__':
