@@ -99,7 +99,7 @@ class TestCase(unittest.TestCase, WebDriver, AppDriver, HttpRequest):
         if title is None:
             raise AssertionError("The assertion title cannot be empty.")
 
-        log.info(f"👀 assertTitle -> {title}.")
+        log.info(f"assertTitle -> {title}.")
         for _ in range(Seldom.timeout + 1):
             try:
                 self.assertEqual(title, Seldom.driver.title)
@@ -119,7 +119,7 @@ class TestCase(unittest.TestCase, WebDriver, AppDriver, HttpRequest):
         if title is None:
             raise AssertionError("The assertion title cannot be empty.")
 
-        log.info(f"👀 assertInTitle -> {title}.")
+        log.info(f"assertInTitle -> {title}.")
         for _ in range(Seldom.timeout + 1):
             try:
                 self.assertIn(title, Seldom.driver.title)
@@ -139,7 +139,7 @@ class TestCase(unittest.TestCase, WebDriver, AppDriver, HttpRequest):
         if url is None:
             raise AssertionError("The assertion URL cannot be empty.")
 
-        log.info(f"👀 assertUrl -> {url}.")
+        log.info(f"assertUrl -> {url}.")
         current_url = unquote(Seldom.driver.current_url)
         for _ in range(Seldom.timeout + 1):
             try:
@@ -160,7 +160,7 @@ class TestCase(unittest.TestCase, WebDriver, AppDriver, HttpRequest):
         if url is None:
             raise AssertionError("The assertion URL cannot be empty.")
 
-        log.info(f"👀 assertInUrl -> {url}.")
+        log.info(f"assertInUrl -> {url}.")
         for _ in range(Seldom.timeout + 1):
             current_url = unquote(Seldom.driver.current_url)
             try:
@@ -182,7 +182,7 @@ class TestCase(unittest.TestCase, WebDriver, AppDriver, HttpRequest):
             raise AssertionError("The assertion text cannot be empty.")
 
         elem = Seldom.driver.find_element(By.TAG_NAME, "html")
-        log.info(f"👀 assertText -> {text}.")
+        log.info(f"assertText -> {text}.")
         for _ in range(Seldom.timeout + 1):
             if elem.is_displayed():
                 try:
@@ -205,7 +205,7 @@ class TestCase(unittest.TestCase, WebDriver, AppDriver, HttpRequest):
 
         elem = Seldom.driver.find_element(By.TAG_NAME, "html")
 
-        log.info(f"👀 assertNotText -> {text}.")
+        log.info(f"assertNotText -> {text}.")
         for _ in range(Seldom.timeout + 1):
             if elem.is_displayed():
                 try:
@@ -226,7 +226,7 @@ class TestCase(unittest.TestCase, WebDriver, AppDriver, HttpRequest):
         if text is None:
             raise NameError("Alert text cannot be empty.")
 
-        log.info(f"👀 assertAlertText -> {text}.")
+        log.info(f"assertAlertText -> {text}.")
         alert_text = Seldom.driver.switch_to.alert.text
         for _ in range(Seldom.timeout + 1):
             try:
@@ -244,7 +244,7 @@ class TestCase(unittest.TestCase, WebDriver, AppDriver, HttpRequest):
         Usage:
         self.assertElement(css="#id")
         """
-        log.info("👀 assertElement.")
+        log.info("assertElement.")
         if msg is None:
             msg = "No element found"
         try:
@@ -262,7 +262,7 @@ class TestCase(unittest.TestCase, WebDriver, AppDriver, HttpRequest):
         Usage:
         self.assertNotElement(css="#id")
         """
-        log.info("👀 assertNotElement.")
+        log.info("assertNotElement.")
         if msg is None:
             msg = "Find the element"
 
@@ -282,7 +282,7 @@ class TestCase(unittest.TestCase, WebDriver, AppDriver, HttpRequest):
         """
         Asserts the HTTP status code
         """
-        log.info(f"👀 assertStatusCode -> {status_code}.")
+        log.info(f"assertStatusCode -> {status_code}.")
         self.assertEqual(ResponseResult.status_code, status_code, msg=msg)
 
     def assertSchema(self, schema, response=None) -> None:
@@ -290,7 +290,7 @@ class TestCase(unittest.TestCase, WebDriver, AppDriver, HttpRequest):
         Assert JSON Schema
         doc: https://json-schema.org/
         """
-        log.info(f"👀 assertSchema -> {formatting(schema)}.")
+        log.info(f"assertSchema -> {formatting(schema)}.")
 
         if response is None:
             response = ResponseResult.response
@@ -304,7 +304,7 @@ class TestCase(unittest.TestCase, WebDriver, AppDriver, HttpRequest):
         """
         Assert JSON data
         """
-        log.info(f"👀 assertJSON -> {assert_json}.")
+        log.info(f"assertJSON -> {assert_json}.")
         if response is None:
             response = ResponseResult.response
 
@@ -321,7 +321,7 @@ class TestCase(unittest.TestCase, WebDriver, AppDriver, HttpRequest):
         Assert path data
         doc: https://jmespath.org/
         """
-        log.info(f"👀 assertPath -> {path} >> {value}.")
+        log.info(f"assertPath -> {path} >> {value}.")
         search_value = jmespath(ResponseResult.response, path)
         self.assertEqual(search_value, value)
 
@@ -330,7 +330,7 @@ class TestCase(unittest.TestCase, WebDriver, AppDriver, HttpRequest):
         Assert path data
         doc: https://jmespath.org/
         """
-        log.info(f"👀 assertInPath -> {path} >> {value}.")
+        log.info(f"assertInPath -> {path} >> {value}.")
         search_value = jmespath(ResponseResult.response, path)
         self.assertIn(value, search_value)
 
